Learn R Programming

geopsych (version 0.1.0)

bes2011: Georeferenced responses of Neighborhood Social Capital Scale from BES2011

Description

Responses of the Neighborhood Social Capital Scale (NSCS) from Baltimore Ecosystem Study (BES) Household Telephone Survey Wave 5 (2011), which excluded the samples from Queen Anne's County. The responses were geocoded and transformed to a SpatialPointsDataFrame.

Usage

data("bes2011")

Arguments

Format

a SpatialPolygonsDataFrame with 1,410 responses on the following 5 items:

willHelp

People in the neighborhood are willing to help one another

closeKnit

This is a close knit neighborhood

trust

People in this neighborhood can be trusted

solComProb

There are many opportunities to meet neighbors and work on community problems

relGroups

Churches, temples and other volunteer groups actively support the neighborhood

Examples

Run this code
data("bes2011")

Run the code above in your browser using DataLab