Learn R Programming

geopsych (version 0.1.0)

bw_gwalpha: Bandwidth Selection for Geographically Weighted Cronbach's Alpha

Description

A function for automatic bandwidth selection to calibrate GWalpha.

Usage

bw_gwalpha(crit, minmax, adaptive = TRUE, tol = 3, max_iter = 100, ...)

Value

a adaptive or fixed distance bandwidth

Arguments

crit

predetermined criterion for reliability level

minmax

a numeric vector of length 2 with the lower and upper bounds of the bandwidth search interval

adaptive

logical; if TRUE (default), the bandwidth bw corresponds to the number of nearest neighbours; if FALSE, bw is a fixed distance

tol

convergence tolerance

max_iter

maximum number of iterations

...

additional arguments passed on to gwalpha().

See Also

gwalpha()