A function for automatic bandwidth selection to calibrate GWalpha.
bw_gwalpha(crit, minmax, adaptive = TRUE, tol = 3, max_iter = 100, ...)a adaptive or fixed distance bandwidth
predetermined criterion for reliability level
a numeric vector of length 2 with the lower and upper bounds of the bandwidth search interval
logical; if TRUE (default), the bandwidth bw
corresponds to the number of nearest neighbours; if FALSE,
bw is a fixed distance
convergence tolerance
maximum number of iterations
additional arguments passed on to gwalpha().
gwalpha()